@@ -76,6 +76,8 @@ pub mod email_analysis;
 pub use self::email_analysis::EmailAnalysis;
 pub mod email_content_match_result;
 pub use self::email_content_match_result::EmailContentMatchResult;
+pub mod email_links_result;
+pub use self::email_links_result::EmailLinksResult;
 pub mod email_preview;
 pub use self::email_preview::EmailPreview;
 pub mod email_projection;
@@ -96,6 +98,8 @@ pub mod export_options;
 pub use self::export_options::ExportOptions;
 pub mod forward_email_options;
 pub use self::forward_email_options::ForwardEmailOptions;
+pub mod gravatar_url;
+pub use self::gravatar_url::GravatarUrl;
 pub mod group_contacts_dto;
 pub use self::group_contacts_dto::GroupContactsDto;
 pub mod group_dto;
